@@ -1,7 +1,7 @@
 #ifndef AL_AL_H
 #define AL_AL_H
 
-#if defined(__cplusplus)
+#ifdef __cplusplus
 extern "C" {
 #endif
 
@@ -15,7 +15,7 @@ extern "C" {
  #endif
 #endif
 
-#if defined(_WIN32)
+#ifdef _WIN32
  #define AL_APIENTRY __cdecl
 #else
  #define AL_APIENTRY
@@ -40,7 +40,7 @@ typedef char ALboolean;
 /** character */
 typedef char ALchar;
 
-/** signed 8-bit 2's complement integer */
+/** signed 8-bit integer */
 #ifdef __sun
 #include <inttypes.h>
 typedef int8_t ALbyte;
@@ -51,37 +51,37 @@ typedef signed char ALbyte;
 /** unsigned 8-bit integer */
 typedef unsigned char ALubyte;
 
-/** signed 16-bit 2's complement integer */
+/** signed 16-bit integer */
 typedef short ALshort;
 
 /** unsigned 16-bit integer */
 typedef unsigned short ALushort;
 
-/** signed 32-bit 2's complement integer */
+/** signed 32-bit integer */
 typedef int ALint;
 
 /** unsigned 32-bit integer */
 typedef unsigned int ALuint;
 
-/** non-negative 32-bit binary integer size */
+/** non-negative 32-bit integer size */
 typedef int ALsizei;
 
-/** enumerated 32-bit value */
+/** 32-bit enumeration value */
 typedef int ALenum;
 
-/** 32-bit IEEE754 floating-point */
+/** 32-bit IEEE-754 floating-point */
 typedef float ALfloat;
 
-/** 64-bit IEEE754 floating-point */
+/** 64-bit IEEE-754 floating-point */
 typedef double ALdouble;
 
-/** void type (for opaque pointers only) */
+/** void type (opaque pointers only) */
 typedef void ALvoid;
 
 
-/* Enumerant values begin at column 50. No tabs. */
+/* Enumeration values begin at column 50. Do not use tabs. */
 
-/** "no distance model" or "no buffer" */
+/** No distance model or no buffer */
 #define AL_NONE                                  0
 
 /** Boolean False. */
@@ -94,10 +94,10 @@ typedef void ALvoid;
 /**
  * Relative source.
  * Type:    ALboolean
- * Range:   [AL_TRUE, AL_FALSE]
+ * Range:   [AL_FALSE, AL_TRUE]
  * Default: AL_FALSE
  *
- * Specifies if the Source has relative coordinates.
+ * Specifies if the source uses relative coordinates.
  */
 #define AL_SOURCE_RELATIVE                       0x202
 
@@ -108,7 +108,8 @@ typedef void ALvoid;
  * Range:   [0 - 360]
  * Default: 360
  *
- * The angle covered by the inner cone, where the source will not attenuate.
+ * The angle covered by the inner cone, the area within which the source will
+ * not be attenuated by direction.
  */
 #define AL_CONE_INNER_ANGLE                      0x1001
 
@@ -117,8 +118,8 @@ typedef void ALvoid;
  * Range:   [0 - 360]
  * Default: 360
  *
- * The angle covered by the outer cone, where the source will be fully
- * attenuated.
+ * The angle covered by the outer cone, the area outside of which the source
+ * will be fully attenuated by direction.
  */
 #define AL_CONE_OUTER_ANGLE                      0x1002
 
@@ -128,7 +129,7 @@ typedef void ALvoid;
  * Range:   [0.5 - 2.0]
  * Default: 1.0
  *
- * A multiplier for the frequency (sample rate) of the source's buffer.
+ * A multiplier for the sample rate of the source's buffer.
  */
 #define AL_PITCH                                 0x1003
 
@@ -139,12 +140,12 @@ typedef void ALvoid;
  *
  * The source or listener location in three dimensional space.
  *
- * OpenAL, like OpenGL, uses a right handed coordinate system, where in a
- * frontal default view X (thumb) points right, Y points up (index finger), and
- * Z points towards the viewer/camera (middle finger).
+ * OpenAL uses a right handed coordinate system, like OpenGL, where with a
+ * default view, X points right (thumb), Y points up (index finger), and Z
+ * points towards the viewer/camera (middle finger).
  *
- * To switch from a left handed coordinate system, flip the sign on the Z
- * coordinate.
+ * To change from or to a left handed coordinate system, negate the Z
+ * component.
  */
 #define AL_POSITION                              0x1004
 
@@ -153,8 +154,11 @@ typedef void ALvoid;
  * Type:    ALfloat[3], ALint[3]
  * Default: {0, 0, 0}
  *
- * Specifies the current direction in local space.
- * A zero-length vector specifies an omni-directional source (cone is ignored).
+ * Specifies the current direction in local space. A zero-length vector
+ * specifies an omni-directional source (cone is ignored).
+ *
+ * To change from or to a left handed coordinate system, negate the Z
+ * component.
  */
 #define AL_DIRECTION                             0x1005
 
@@ -163,26 +167,30 @@ typedef void ALvoid;
  * Type:    ALfloat[3], ALint[3]
  * Default: {0, 0, 0}
  *
- * Specifies the current velocity in local space.
+ * Specifies the current velocity, relative to the position.
+ *
+ * To change from or to a left handed coordinate system, negate the Z
+ * component.
  */
 #define AL_VELOCITY                              0x1006
 
 /**
  * Source looping.
  * Type:    ALboolean
- * Range:   [AL_TRUE, AL_FALSE]
+ * Range:   [AL_FALSE, AL_TRUE]
  * Default: AL_FALSE
  *
- * Specifies whether source is looping.
+ * Specifies whether source playback loops.
  */
 #define AL_LOOPING                               0x1007
 
 /**
  * Source buffer.
- * Type:  ALuint
- * Range: any valid Buffer.
+ * Type:    ALuint
+ * Range:   any valid Buffer ID
+ * Default: AL_NONE
  *
- * Specifies the buffer to provide sound samples.
+ * Specifies the buffer to provide sound samples for a source.
  */
 #define AL_BUFFER                                0x1009
 
@@ -191,12 +199,12 @@ typedef void ALvoid;
  * Type:  ALfloat
  * Range: [0.0 - ]
  *
- * A value of 1.0 means unattenuated. Each division by 2 equals an attenuation
- * of about -6dB. Each multiplicaton by 2 equals an amplification of about
- * +6dB.
+ * For sources, an initial linear gain value (before attenuation is applied).
+ * For the listener, an output linear gain adjustment.
  *
- * A value of 0.0 is meaningless with respect to a logarithmic scale; it is
- * silent.
+ * A value of 1.0 means unattenuated. Each division by 2 equals an attenuation
+ * of about -6dB. Each multiplication by 2 equals an amplification of about
+ * +6dB.
  */
 #define AL_GAIN                                  0x100A
 
@@ -205,8 +213,8 @@ typedef void ALvoid;
  * Type:  ALfloat
  * Range: [0.0 - 1.0]
  *
- * The minimum gain allowed for a source, after distance and cone attenation is
- * applied (if applicable).
+ * The minimum gain allowed for a source, after distance and cone attenuation
+ * are applied (if applicable).
  */
 #define AL_MIN_GAIN                              0x100D
 
@@ -215,26 +223,28 @@ typedef void ALvoid;
  * Type:  ALfloat
  * Range: [0.0 - 1.0]
  *
- * The maximum gain allowed for a source, after distance and cone attenation is
- * applied (if applicable).
+ * The maximum gain allowed for a source, after distance and cone attenuation
+ * are applied (if applicable).
  */
 #define AL_MAX_GAIN                              0x100E
 
 /**
  * Listener orientation.
- * Type: ALfloat[6]
+ * Type:    ALfloat[6]
  * Default: {0.0, 0.0, -1.0, 0.0, 1.0, 0.0}
  *
  * Effectively two three dimensional vectors. The first vector is the front (or
- * "at") and the second is the top (or "up").
+ * "at") and the second is the top (or "up"). Both vectors are relative to the
+ * listener position.
  *
- * Both vectors are in local space.
+ * To change from or to a left handed coordinate system, negate the Z
+ * component of both vectors.
  */
 #define AL_ORIENTATION                           0x100F
 
 /**
  * Source state (query only).
- * Type:  ALint
+ * Type:  ALenum
  * Range: [AL_INITIAL, AL_PLAYING, AL_PAUSED, AL_STOPPED]
  */
 #define AL_SOURCE_STATE                          0x1010
@@ -272,9 +282,9 @@ typedef void ALvoid;
  * Range:   [0.0 - ]
  * Default: 1.0
  *
- * The distance in units that no attenuation occurs.
+ * The distance in units that no distance attenuation occurs.
  *
- * At 0.0, no distance attenuation ever occurs on non-linear attenuation models.
+ * At 0.0, no distance attenuation occurs with non-linear attenuation models.
  */
 #define AL_REFERENCE_DISTANCE                    0x1020
 
@@ -297,7 +307,7 @@ typedef void ALvoid;
  * Default: 0.0
  *
  * The gain attenuation applied when the listener is outside of the source's
- * outer cone.
+ * outer cone angle.
  */
 #define AL_CONE_OUTER_GAIN                       0x1022
 
@@ -313,16 +323,16 @@ typedef void ALvoid;
  */
 #define AL_MAX_DISTANCE                          0x1023
 
-/** Source buffer position, in seconds */
+/** Source buffer offset, in seconds */
 #define AL_SEC_OFFSET                            0x1024
-/** Source buffer position, in sample frames */
+/** Source buffer offset, in sample frames */
 #define AL_SAMPLE_OFFSET                         0x1025
-/** Source buffer position, in bytes */
+/** Source buffer offset, in bytes */
 #define AL_BYTE_OFFSET                           0x1026
 
 /**
  * Source type (query only).
- * Type:  ALint
+ * Type:  ALenum
  * Range: [AL_STATIC, AL_STREAMING, AL_UNDETERMINED]
  *
  * A Source is Static if a Buffer has been attached using AL_BUFFER.
@@ -349,13 +359,13 @@ typedef void ALvoid;
 /** Signed 16-bit stereo buffer format. */
 #define AL_FORMAT_STEREO16                       0x1103
 
-/** Buffer frequency (query only). */
+/** Buffer frequency/sample rate (query only). */
 #define AL_FREQUENCY                             0x2001
 /** Buffer bits per sample (query only). */
 #define AL_BITS                                  0x2002
 /** Buffer channel count (query only). */
 #define AL_CHANNELS                              0x2003
-/** Buffer data size (query only). */
+/** Buffer data size in bytes (query only). */
 #define AL_SIZE                                  0x2004
 
 /* Buffer state. Not for public use. */
@@ -367,32 +377,31 @@ typedef void ALvoid;
 /** No error. */
 #define AL_NO_ERROR                              0
 
-/** Invalid name paramater passed to AL call. */
+/** Invalid name (ID) passed to an AL call. */
 #define AL_INVALID_NAME                          0xA001
 
-/** Invalid enum parameter passed to AL call. */
+/** Invalid enumeration passed to AL call. */
 #define AL_INVALID_ENUM                          0xA002
 
-/** Invalid value parameter passed to AL call. */
+/** Invalid value passed to AL call. */
 #define AL_INVALID_VALUE                         0xA003
 
 /** Illegal AL call. */
 #define AL_INVALID_OPERATION                     0xA004
 
-/** Not enough memory. */
+/** Not enough memory to execute the AL call. */
 #define AL_OUT_OF_MEMORY                         0xA005
 
 
-/** Context string: Vendor ID. */
+/** Context string: Vendor name. */
 #define AL_VENDOR                                0xB001
 /** Context string: Version. */
 #define AL_VERSION                               0xB002
-/** Context string: Renderer ID. */
+/** Context string: Renderer name. */
 #define AL_RENDERER                              0xB003
 /** Context string: Space-separated extension list. */
 #define AL_EXTENSIONS                            0xB004
 
-
 /**
  * Doppler scale.
  * Type:    ALfloat
@@ -402,7 +411,6 @@ typedef void ALvoid;
  * Scale for source and listener velocities.
  */
 #define AL_DOPPLER_FACTOR                        0xC000
-AL_API void AL_APIENTRY alDopplerFactor(ALfloat value);
 
 /**
  * Doppler velocity (deprecated).
@@ -410,7 +418,6 @@ AL_API void AL_APIENTRY alDopplerFactor(ALfloat value);
  * A multiplier applied to the Speed of Sound.
  */
 #define AL_DOPPLER_VELOCITY                      0xC001
-AL_API void AL_APIENTRY alDopplerVelocity(ALfloat value);
 
 /**
  * Speed of Sound, in units per second.
@@ -419,14 +426,13 @@ AL_API void AL_APIENTRY alDopplerVelocity(ALfloat value);
  * Default: 343.3
  *
  * The speed at which sound waves are assumed to travel, when calculating the
- * doppler effect.
+ * doppler effect from source and listener velocities.
  */
 #define AL_SPEED_OF_SOUND                        0xC003
-AL_API void AL_APIENTRY alSpeedOfSound(ALfloat value);
 
 /**
  * Distance attenuation model.
- * Type:    ALint
+ * Type:    ALenum
  * Range:   [AL_NONE, AL_INVERSE_DISTANCE, AL_INVERSE_DISTANCE_CLAMPED,
  *           AL_LINEAR_DISTANCE, AL_LINEAR_DISTANCE_CLAMPED,
  *           AL_EXPONENT_DISTANCE, AL_EXPONENT_DISTANCE_CLAMPED]
@@ -443,7 +449,6 @@ AL_API void AL_APIENTRY alSpeedOfSound(ALfloat value);
  * distance calculated is clamped between the reference and max distances.
  */
 #define AL_DISTANCE_MODEL                        0xD000
-AL_API void AL_APIENTRY alDistanceModel(ALenum distanceModel);
 
 /* Distance model values. */
 #define AL_INVERSE_DISTANCE                      0xD001
@@ -453,12 +458,19 @@ AL_API void AL_APIENTRY alDistanceModel(ALenum distanceModel);
 #define AL_EXPONENT_DISTANCE                     0xD005
 #define AL_EXPONENT_DISTANCE_CLAMPED             0xD006
 
+#ifndef AL_NO_PROTOTYPES
 /* Renderer State management. */
 AL_API void AL_APIENTRY alEnable(ALenum capability);
 AL_API void AL_APIENTRY alDisable(ALenum capability);
 AL_API ALboolean AL_APIENTRY alIsEnabled(ALenum capability);
 
-/* State retrieval. */
+/* Context state setting. */
+AL_API void AL_APIENTRY alDopplerFactor(ALfloat value);
+AL_API void AL_APIENTRY alDopplerVelocity(ALfloat value);
+AL_API void AL_APIENTRY alSpeedOfSound(ALfloat value);
+AL_API void AL_APIENTRY alDistanceModel(ALenum distanceModel);
+
+/* Context state retrieval. */
 AL_API const ALchar* AL_APIENTRY alGetString(ALenum param);
 AL_API void AL_APIENTRY alGetBooleanv(ALenum param, ALboolean *values);
 AL_API void AL_APIENTRY alGetIntegerv(ALenum param, ALint *values);
@@ -469,9 +481,10 @@ AL_API ALint AL_APIENTRY alGetInteger(ALenum param);
 AL_API ALfloat AL_APIENTRY alGetFloat(ALenum param);
 AL_API ALdouble AL_APIENTRY alGetDouble(ALenum param);
 
-/* Error retrieval. */
-
-/** Obtain the first error generated in the AL context since the last check. */
+/**
+ * Obtain the first error generated in the AL context since the last call to
+ * this function.
+ */
 AL_API ALenum AL_APIENTRY alGetError(void);
 
 /** Query for the presence of an extension on the AL context. */
@@ -487,7 +500,7 @@ AL_API void* AL_APIENTRY alGetProcAddress(const ALchar *fname);
 AL_API ALenum AL_APIENTRY alGetEnumValue(const ALchar *ename);
 
 
-/* Set Listener parameters */
+/* Set listener parameters. */
 AL_API void AL_APIENTRY alListenerf(ALenum param, ALfloat value);
 AL_API void AL_APIENTRY alListener3f(ALenum param, ALfloat value1, ALfloat value2, ALfloat value3);
 AL_API void AL_APIENTRY alListenerfv(ALenum param, const ALfloat *values);
@@ -495,7 +508,7 @@ AL_API void AL_APIENTRY alListeneri(ALenum param, ALint value);
 AL_API void AL_APIENTRY alListener3i(ALenum param, ALint value1, ALint value2, ALint value3);
 AL_API void AL_APIENTRY alListeneriv(ALenum param, const ALint *values);
 
-/* Get Listener parameters */
+/* Get listener parameters. */
 AL_API void AL_APIENTRY alGetListenerf(ALenum param, ALfloat *value);
 AL_API void AL_APIENTRY alGetListener3f(ALenum param, ALfloat *value1, ALfloat *value2, ALfloat *value3);
 AL_API void AL_APIENTRY alGetListenerfv(ALenum param, ALfloat *values);
@@ -504,14 +517,14 @@ AL_API void AL_APIENTRY alGetListener3i(ALenum param, ALint *value1, ALint *valu
 AL_API void AL_APIENTRY alGetListeneriv(ALenum param, ALint *values);
 
 
-/** Create Source objects. */
+/** Create source objects. */
 AL_API void AL_APIENTRY alGenSources(ALsizei n, ALuint *sources);
-/** Delete Source objects. */
+/** Delete source objects. */
 AL_API void AL_APIENTRY alDeleteSources(ALsizei n, const ALuint *sources);
-/** Verify a handle is a valid Source. */
+/** Verify an ID is for a valid source. */
 AL_API ALboolean AL_APIENTRY alIsSource(ALuint source);
 
-/* Set Source parameters. */
+/* Set source parameters. */
 AL_API void AL_APIENTRY alSourcef(ALuint source, ALenum param, ALfloat value);
 AL_API void AL_APIENTRY alSource3f(ALuint source, ALenum param, ALfloat value1, ALfloat value2, ALfloat value3);
 AL_API void AL_APIENTRY alSourcefv(ALuint source, ALenum param, const ALfloat *values);
@@ -519,7 +532,7 @@ AL_API void AL_APIENTRY alSourcei(ALuint source, ALenum param, ALint value);
 AL_API void AL_APIENTRY alSource3i(ALuint source, ALenum param, ALint value1, ALint value2, ALint value3);
 AL_API void AL_APIENTRY alSourceiv(ALuint source, ALenum param, const ALint *values);
 
-/* Get Source parameters. */
+/* Get source parameters. */
 AL_API void AL_APIENTRY alGetSourcef(ALuint source, ALenum param, ALfloat *value);
 AL_API void AL_APIENTRY alGetSource3f(ALuint source, ALenum param, ALfloat *value1, ALfloat *value2, ALfloat *value3);
 AL_API void AL_APIENTRY alGetSourcefv(ALuint source, ALenum param, ALfloat *values);
@@ -528,41 +541,44 @@ AL_API void AL_APIENTRY alGetSource3i(ALuint source, ALenum param, ALint *value1
 AL_API void AL_APIENTRY alGetSourceiv(ALuint source,  ALenum param, ALint *values);
 
 
-/** Play, replay, or resume (if paused) a list of Sources */
-AL_API void AL_APIENTRY alSourcePlayv(ALsizei n, const ALuint *sources);
-/** Stop a list of Sources */
-AL_API void AL_APIENTRY alSourceStopv(ALsizei n, const ALuint *sources);
-/** Rewind a list of Sources */
-AL_API void AL_APIENTRY alSourceRewindv(ALsizei n, const ALuint *sources);
-/** Pause a list of Sources */
-AL_API void AL_APIENTRY alSourcePausev(ALsizei n, const ALuint *sources);
-
-/** Play, replay, or resume a Source */
+/** Play, restart, or resume a source, setting its state to AL_PLAYING. */
 AL_API void AL_APIENTRY alSourcePlay(ALuint source);
-/** Stop a Source */
+/** Stop a source, setting its state to AL_STOPPED if playing or paused. */
 AL_API void AL_APIENTRY alSourceStop(ALuint source);
-/** Rewind a Source (set playback postiton to beginning) */
+/** Rewind a source, setting its state to AL_INITIAL. */
 AL_API void AL_APIENTRY alSourceRewind(ALuint source);
-/** Pause a Source */
+/** Pause a source, setting its state to AL_PAUSED if playing. */
 AL_API void AL_APIENTRY alSourcePause(ALuint source);
 
+/** Play, restart, or resume a list of sources atomically. */
+AL_API void AL_APIENTRY alSourcePlayv(ALsizei n, const ALuint *sources);
+/** Stop a list of sources atomically. */
+AL_API void AL_APIENTRY alSourceStopv(ALsizei n, const ALuint *sources);
+/** Rewind a list of sources atomically. */
+AL_API void AL_APIENTRY alSourceRewindv(ALsizei n, const ALuint *sources);
+/** Pause a list of sources atomically. */
+AL_API void AL_APIENTRY alSourcePausev(ALsizei n, const ALuint *sources);
+
 /** Queue buffers onto a source */
 AL_API void AL_APIENTRY alSourceQueueBuffers(ALuint source, ALsizei nb, const ALuint *buffers);
 /** Unqueue processed buffers from a source */
 AL_API void AL_APIENTRY alSourceUnqueueBuffers(ALuint source, ALsizei nb, ALuint *buffers);
 
 
-/** Create Buffer objects */
+/** Create buffer objects */
 AL_API void AL_APIENTRY alGenBuffers(ALsizei n, ALuint *buffers);
-/** Delete Buffer objects */
+/** Delete buffer objects */
 AL_API void AL_APIENTRY alDeleteBuffers(ALsizei n, const ALuint *buffers);
-/** Verify a handle is a valid Buffer */
+/** Verify an ID is a valid buffer (including the NULL buffer) */
 AL_API ALboolean AL_APIENTRY alIsBuffer(ALuint buffer);
 
-/** Specifies the data to be copied into a buffer */
-AL_API void AL_APIENTRY alBufferData(ALuint buffer, ALenum format, const ALvoid *data, ALsizei size, ALsizei freq);
+/**
+ * Copies data into the buffer, interpreting it using the specified format and
+ * samplerate.
+ */
+AL_API void AL_APIENTRY alBufferData(ALuint buffer, ALenum format, const ALvoid *data, ALsizei size, ALsizei samplerate);
 
-/* Set Buffer parameters, */
+/* Set buffer parameters. */
 AL_API void AL_APIENTRY alBufferf(ALuint buffer, ALenum param, ALfloat value);
 AL_API void AL_APIENTRY alBuffer3f(ALuint buffer, ALenum param, ALfloat value1, ALfloat value2, ALfloat value3);
 AL_API void AL_APIENTRY alBufferfv(ALuint buffer, ALenum param, const ALfloat *values);
@@ -570,15 +586,18 @@ AL_API void AL_APIENTRY alBufferi(ALuint buffer, ALenum param, ALint value);
 AL_API void AL_APIENTRY alBuffer3i(ALuint buffer, ALenum param, ALint value1, ALint value2, ALint value3);
 AL_API void AL_APIENTRY alBufferiv(ALuint buffer, ALenum param, const ALint *values);
 
-/* Get Buffer parameters. */
+/* Get buffer parameters. */
 AL_API void AL_APIENTRY alGetBufferf(ALuint buffer, ALenum param, ALfloat *value);
 AL_API void AL_APIENTRY alGetBuffer3f(ALuint buffer, ALenum param, ALfloat *value1, ALfloat *value2, ALfloat *value3);
 AL_API void AL_APIENTRY alGetBufferfv(ALuint buffer, ALenum param, ALfloat *values);
 AL_API void AL_APIENTRY alGetBufferi(ALuint buffer, ALenum param, ALint *value);
 AL_API void AL_APIENTRY alGetBuffer3i(ALuint buffer, ALenum param, ALint *value1, ALint *value2, ALint *value3);
 AL_API void AL_APIENTRY alGetBufferiv(ALuint buffer, ALenum param, ALint *values);
+#endif /* AL_NO_PROTOTYPES */
 
-/* Pointer-to-function type, useful for dynamically getting AL entry points. */
+/* Pointer-to-function types, useful for storing dynamically loaded AL entry
+ * points.
+ */
 typedef void          (AL_APIENTRY *LPALENABLE)(ALenum capability);
 typedef void          (AL_APIENTRY *LPALDISABLE)(ALenum capability);
 typedef ALboolean     (AL_APIENTRY *LPALISENABLED)(ALenum capability);
@@ -635,7 +654,7 @@ typedef void          (AL_APIENTRY *LPALSOURCEUNQUEUEBUFFERS)(ALuint source, ALs
 typedef void          (AL_APIENTRY *LPALGENBUFFERS)(ALsizei n, ALuint *buffers);
 typedef void          (AL_APIENTRY *LPALDELETEBUFFERS)(ALsizei n, const ALuint *buffers);
 typedef ALboolean     (AL_APIENTRY *LPALISBUFFER)(ALuint buffer);
-typedef void          (AL_APIENTRY *LPALBUFFERDATA)(ALuint buffer, ALenum format, const ALvoid *data, ALsizei size, ALsizei freq);
+typedef void          (AL_APIENTRY *LPALBUFFERDATA)(ALuint buffer, ALenum format, const ALvoid *data, ALsizei size, ALsizei samplerate);
 typedef void          (AL_APIENTRY *LPALBUFFERF)(ALuint buffer, ALenum param, ALfloat value);
 typedef void          (AL_APIENTRY *LPALBUFFER3F)(ALuint buffer, ALenum param, ALfloat value1, ALfloat value2, ALfloat value3);
 typedef void          (AL_APIENTRY *LPALBUFFERFV)(ALuint buffer, ALenum param, const ALfloat *values);
@@ -653,7 +672,7 @@ typedef void          (AL_APIENTRY *LPALDOPPLERVELOCITY)(ALfloat value);
 typedef void          (AL_APIENTRY *LPALSPEEDOFSOUND)(ALfloat value);
 typedef void          (AL_APIENTRY *LPALDISTANCEMODEL)(ALenum distanceModel);
 
-#if defined(__cplusplus)
+#ifdef __cplusplus
 }  /* extern "C" */
 #endif
 
